pub struct InterfaceConfig {
pub interface: InterfaceInfo,
pub server: ServerInfo,
/* private fields */
}Expand description
This struct contains everything necessary to establish an innernet connection: information about a local innernet interface and a remote innernet server.
Fields
interface: InterfaceInfoThe information to bring up the interface.
server: ServerInfoThe necessary contact information for the server.
Implementations
Sourceimpl InterfaceConfig
impl InterfaceConfig
Sourcepub fn save_new(
&self,
path: impl AsRef<Path>,
mode: u32,
) -> Result<(), WrappedIoError>
pub fn save_new( &self, path: impl AsRef<Path>, mode: u32, ) -> Result<(), WrappedIoError>
Save a new config file, failing if it already exists.
Sourcepub fn save(
&self,
config_dir: &Path,
interface: &InterfaceName,
) -> Result<PathBuf, Error>
pub fn save( &self, config_dir: &Path, interface: &InterfaceName, ) -> Result<PathBuf, Error>
Overwrites the config file if it already exists.
pub fn from_file<P: AsRef<Path>>(path: P) -> Result<Self, Error>
pub fn from_interface( config_dir: &Path, interface: &InterfaceName, ) -> Result<Self, Error>
pub fn get_path(config_dir: &Path, interface: &InterfaceName) -> PathBuf
pub fn build_config_file_path( config_dir: &Path, interface: &InterfaceName, ) -> Result<PathBuf, WrappedIoError>
pub fn peer_endpoint_overrides(&self) -> &BTreeMap<IpAddr, Endpoint>
pub fn set_endpoint_override_for_peer( &mut self, peer_ip: IpAddr, endpoint: Endpoint, )
pub fn unset_endpoint_override_for_peer(&mut self, peer_ip: IpAddr)