Module prompts

Module prompts 

Enums

Prefill

Statics

THEME

Functions

add_association
add_cidr
Bring up a prompt to create a new CIDR. Returns the peer request.
add_peer
Bring up a prompt to create a new peer. Returns the peer request.
choose_association
choose_cidr
confirm
delete_association
delete_cidr
Bring up a prompt to delete a CIDR. Returns the peer request.
enable_or_disable_peer
Presents a selection and confirmation of eligible peers for either disabling or enabling, and returns back the ID of the selected peer.
ensure_interactive
input
input_external_endpoint
ip_auto_detection_flow
rename_cidr
Bring up a prompt to rename an existing CIDR. Returns the CIDR request.
rename_peer
Bring up a prompt to rename an existing peer. Returns the peer request.
select
set_listen_port
unspecified_ip_and_auto_detection_flow
write_peer_invitation
Confirm and write a innernet invitation file after a peer has been created.