Module types

Module types 

Structs

AddCidrOpts
AddDeleteAssociationOpts
AddPeerOpts
Association
AssociationContents
Cidr
CidrContents
CidrTree
DeleteCidrOpts
EnableDisablePeerOpts
Endpoint
An external endpoint that supports both IP and domain name hosts.
Hostname
HostsOpt
InstallOpts
Interface
ListenPortOpts
NatOpts
NetworkOpts
OverrideEndpointOpts
Peer
PeerContents
PeerDiff
Encompasses the logic for comparing the peer configuration currently on the WireGuard interface to a (potentially) more current peer configuration from the innernet server.
RedeemContents
RenameCidrOpts
RenamePeerOpts
ServerCapabilities
This model is sent as a response to the /capabilities endpoint.
State
This model is sent as a response to the /state endpoint, and is meant to include all the data a client needs to update its WireGuard interface.
Timestring
WrappedIoError

Enums

EndpointContents
PeerChange

Traits

IoErrorContext