pub struct NatOpts {
pub no_nat_traversal: bool,
pub exclude_nat_candidates: Vec<IpNet>,
pub no_nat_candidates: bool,
}Fields
no_nat_traversal: boolDon’t attempt NAT traversal. Note that this still will report candidates unless you also specify to exclude all NAT candidates.
exclude_nat_candidates: Vec<IpNet>Exclude one or more CIDRs from NAT candidate reporting. ex. –exclude-nat-candidates ‘0.0.0.0/0’ would report no candidates.
no_nat_candidates: boolDon’t report any candidates to coordinating server. Shorthand for –exclude-nat-candidates ‘0.0.0.0/0’.
Implementations
Sourceimpl NatOpts
impl NatOpts
pub fn all_disabled() -> Self
Sourcepub fn is_excluded(&self, ip: IpAddr) -> bool
pub fn is_excluded(&self, ip: IpAddr) -> bool
Check if an IP is allowed to be reported as a candidate.