pub struct OverridePeerEndpointOpts {
pub name: Option<Hostname>,
pub endpoint: Option<Endpoint>,
pub unset: bool,
pub yes: bool,
}Fields
name: Option<Hostname>Name of peer whose endpoint you want to override
endpoint: Option<Endpoint>The external endpoint that you’d like to use for a given peer
unset: boolUnset an existing local endpoint override for this peer
yes: boolBypass confirmation