Enums
Statics
Functions
- add_
association - add_
cidr - Bring up a prompt to create a new CIDR. Returns the peer request.
- add_
peer - Bring up a prompt to create a new peer. Returns the peer request.
- choose_
association - choose_
cidr - confirm
- delete_
association - delete_
cidr - Bring up a prompt to delete a CIDR. Returns the peer request.
- enable_
or_ disable_ peer - Presents a selection and confirmation of eligible peers for either disabling or enabling, and returns back the ID of the selected peer.
- ensure_
interactive - input
- input_
external_ endpoint - ip_
auto_ detection_ flow - rename_
cidr - Bring up a prompt to rename an existing CIDR. Returns the CIDR request.
- rename_
peer - Bring up a prompt to rename an existing peer. Returns the peer request.
- select
- set_
listen_ port - unspecified_
ip_ and_ auto_ detection_ flow - write_
peer_ invitation - Confirm and write a innernet invitation file after a peer has been created.