Struct NetworkOpts

pub struct NetworkOpts {
    pub no_routing: bool,
    pub backend: Backend,
    pub mtu: Option<u32>,
}

Fields

no_routing: bool

Whether the routing should be done by innernet or is done by an external tool like e.g. babeld.

backend: Backend

Specify a WireGuard backend to use. If not set, innernet will auto-select based on availability.

mtu: Option<u32>

Specify the desired MTU for your interface (default: 1280).