pub struct OverrideEndpointOpts {
pub endpoint: Option<Endpoint>,
pub unset: bool,
pub yes: bool,
}Fields
endpoint: Option<Endpoint>The external endpoint that you’d like the innernet server to broadcast to other peers. The IP address may be unspecified (all zeros), in which case the server will try to resolve it based on its most recent connection. The port will still be used, even if you decide to use an unspecified IP address.
unset: boolUnset an existing override to use the automatic endpoint discovery
yes: boolBypass confirmation