Struct State

pub struct State {
    pub peers: Vec<Peer>,
    pub cidrs: Vec<Cidr>,
}
This model is sent as a response to the /state endpoint, and is meant to include all the data a client needs to update its WireGuard interface.

Fields

peers: Vec<Peer>

This list will be only the peers visible to the user requesting this information, not including disabled peers or peers from other CIDRs that the user’s CIDR is not authorized to communicate with.

cidrs: Vec<Cidr>

At the moment, this is all CIDRs, regardless of whether the peer is eligible to communicate with them or not.